Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(803)

Unified Diff: src/gpu/GrRenderTargetPriv.h

Issue 1083133002: Rename GrStencilBuffer to GrStencilAttachment (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Align data member Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrRenderTarget.cpp ('k') | src/gpu/GrStencilAttachment.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrRenderTargetPriv.h
diff --git a/src/gpu/GrRenderTargetPriv.h b/src/gpu/GrRenderTargetPriv.h
index 92ee30e49f68531077371a45a32a886d6e241175..59262f4b11229df0891dd3461476e16e24cb76fe 100644
--- a/src/gpu/GrRenderTargetPriv.h
+++ b/src/gpu/GrRenderTargetPriv.h
@@ -16,17 +16,17 @@
class GrRenderTargetPriv {
public:
/**
* GrStencilBuffer is not part of the public API.
*/
- GrStencilBuffer* getStencilBuffer() const { return fRenderTarget->fStencilBuffer; }
+ GrStencilAttachment* getStencilAttachment() const { return fRenderTarget->fStencilAttachment; }
/**
* If this render target already has a stencil buffer, return it. Otherwise attempt to attach
* one.
*/
- GrStencilBuffer* attachStencilBuffer() const;
+ GrStencilAttachment* attachStencilAttachment() const;
- void didAttachStencilBuffer(GrStencilBuffer*);
+ void didAttachStencilAttachment(GrStencilAttachment*);
private:
explicit GrRenderTargetPriv(GrRenderTarget* renderTarget) : fRenderTarget(renderTarget) {}
« no previous file with comments | « src/gpu/GrRenderTarget.cpp ('k') | src/gpu/GrStencilAttachment.h » ('j') | no next file with comments »
@@ -16,17 +16,17 @@
public:
/**
- * GrStencilBuffer is not part of the public API.
+ * GrStencilAttachment is not part of the public API.
*/

Powered by Google App Engine
This is Rietveld 408576698